@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2015-01-17'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-01-20'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,22 +323,24 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.47 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-01-17.
+This document describes version 0.48 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-01-20.
 
 =head1 DESCRIPTION
 
 
+{en_US 
 The example(s) in this package are for demonstrating how the function metadata
 is converted into CLI help example (produced by C<--help> or C<--help --verbose>).
 Also for testing how it is converted into POD for scripts (i.e. the C<OPTIONS>
 section).
+}
 
 =head1 FUNCTIONS
 
 
 =head2 demo_cli_opts(%args) -> [status, msg, result, meta]
 
-Summary for `demo_cli_opts`.
+{en_US Summary for `demo_cli_opts`}.
 
 Examples:
 
@@ -354,6 +356,7 @@ Summary for an example.
 A second example.
 
 
+{en_US 
 Description for C<demo_cli_opts>.
 
 This is another paragraph from the description. Description by default is
@@ -361,37 +364,44 @@ assumed to be marked up in I<Markdown> (currently referring to CommonMark).
 
  This paragraph should be set in verbatim.
 
+}
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<are_baz> => I<bool>
 
-This demonstrate negation of --are-foo to --arent-foo.
+{en_US This demonstrate negation of --are-foo to --arent-foo}.
 
 =item * B<array1>* => I<array[str]>
 
-Positional, greedy, and plural.
+{en_US Positional, greedy, and plural}.
 
+{en_US 
 Argument with non-scalar types (like array or hash) can be specified in the CLI
 using C<--ARG-json> or C<--ARG-yaml>. Arguments with type of array of string can
 also be specified using multiple C<--ARG> options.
 
 This option also links to another option.
+}
 
 =item * B<bool1> => I<bool>
 
-A bool option.
+{en_US A bool option}.
 
+{en_US 
 CLI framework should generate C<--nobool1> (and C<--nobool1>) automatically.
 
 This option has an alias, C<-z>. Because the alias has its own
 summary/description, it will be displayed separately.
+}
 
 =item * B<flag1> => I<bool>
 
-A flag option.
+{en_US A flag option}.
 
+{en_US 
 A flag option is a bool option with the value of 1 (true). It is meant to
 activate something if specified and there is no notion of disabling by
 specifying the opposite. Thus the CLI framework should not generate a
@@ -400,62 +410,76 @@ C<--noflag1> option.
 This flag has an alias C<-f> with no summary/description nor code. So the CLI
 framework should display the alias along with the option. Note that short
 (single-letter) options/aliases do not get C<--noX>.
+}
 
 =item * B<full> => I<bool> (default: 1)
 
-Turn on full processing.
+{en_US Turn on full processing}.
 
+{en_US 
 Another bool option with on default.
 
 CLI framework should perhaps show C<--nobool2> instead of C<--bool2> because
 C<--bool2> is active by default. And if it does so, it should also show the
 negative summary in the C<summary.alt.bool.not> attribute instead of the normal
 C<summary> property.
+}
 
 =item * B<full2> => I<bool> (default: 1)
 
-Use full processing (2).
+{en_US Use full processing (2)}.
 
+{en_US 
 Another bool option with on default. Because this option does not have
 C<summary.alt.bool.not>, CLI framework should not show any summary, despite the
 existence of C<summary>.
+}
 
 =item * B<gender> => I<str>
 
-A string option.
+{en_US A string option}.
 
+{en_US 
 This option contains flag aliases that have code.
+}
 
 =item * B<hash1> => I<hash> (default: {default=>1})
 
-Demonstrate hash argument with default value from schema.
+{en_US Demonstrate hash argument with default value from schema}.
 
 =item * B<input> => I<buf>
 
-Specify input.
+{en_US Specify input}.
 
+{en_US 
 This option demonstrates the C<cmdline_src> property. Also, since schema type is
 C<buf>, we know that the value is binary data. CLI framework will provide
 C<--input-base64> to allow specifying binary data encoded in base64.
+}
 
 =item * B<int1>* => I<int>
 
+{en_US 
 Demonstrate an option with no summary. And a required option.
+}
 
 =item * B<int2> => I<int> (default: 10)
 
-Another int option.
+{en_US Another int option}.
 
+{en_US 
 Demonstrate a scalar/simple default value.
+}
 
 =item * B<is_bar> => I<bool>
 
-This demonstrate negation of --is-foo to --isnt-foo.
+{en_US This demonstrate negation of --is-foo to --isnt-foo}.
 
 =item * B<output> => I<str>
 
-Specify output filename.
+{en_US Specify output filename}.
 
+{en_US 
 This option demonstrates how the option would be displayed in the help/usage.
 Due to the C<x.schema.entity> attribute giving hint about what the value is, CLI
 framework can show:
@@ -466,15 +490,17 @@ instead of the plain and less informative:
 
  --output=s
 
+}
+
 =item * B<pass> => I<str>
 
 =item * B<str1>* => I<str>
 
-A required option as well as positional argument.
+{en_US A required option as well as positional argument}.
 
 =item * B<with_foo> => I<bool>
 
-This demonstrate negation of --with-foo to --without-foo.
+{en_US This demonstrate negation of --with-foo to --without-foo}.
 
 =back
 
@@ -492,7 +518,7 @@ Return value:  (any)
 
 =head2 demo_cli_opts_shorter(%args) -> [status, msg, result, meta]
 
-Function summary.
+{en_US Function summary}.
 
 Examples:
 
@@ -508,13 +534,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<bool1> => I<bool>
 
-Another bool option.
+{en_US Another bool option}.
 
 =item * B<flag1> => I<bool>
 
 =item * B<str1>* => I<str>
 
-A required option as well as positional argument.
+{en_US A required option as well as positional argument}.
 
 =back
 
