@@ -1,7 +1,7 @@
 package Perinci::Examples::CmdLineSrc;
 
-our $DATE = '2015-01-17'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-01-20'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010;
 use strict;
@@ -189,14 +189,14 @@ Perinci::Examples::CmdLineSrc - Examples for using cmdline_src function property
 
 =head1 VERSION
 
-This document describes version 0.47 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-01-17.
+This document describes version 0.48 of Perinci::Examples::CmdLineSrc (from Perl distribution Perinci-Examples), released on 2015-01-20.
 
 =head1 FUNCTIONS
 
 
 =head2 cmdline_src_file(%args) -> [status, msg, result, meta]
 
-This function has args with cmdline_src _file.
+{en_US This function has args with cmdline_src _file}.
 
 Arguments ('*' denotes required arguments):
 
@@ -222,7 +222,7 @@ Return value:  (any)
 
 =head2 cmdline_src_invalid_arg_type(%args) -> [status, msg, result, meta]
 
-This function has non-str/non-array arg with cmdline_src.
+{en_US This function has non-str/non-array arg with cmdline_src}.
 
 Arguments ('*' denotes required arguments):
 
@@ -246,7 +246,7 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin(%args) -> [status, msg, result, meta]
 
-This function has multiple args with cmdline_src stdin/stdin_or_files.
+{en_US This function has multiple args with cmdline_src stdin/stdin_or_files}.
 
 Arguments ('*' denotes required arguments):
 
@@ -272,9 +272,11 @@ Return value:  (any)
 
 =head2 cmdline_src_multi_stdin_line(%args) -> [status, msg, result, meta]
 
-This function has several stdin_line arguments.
+{en_US This function has several stdin_line arguments}.
 
+{en_US 
 And one also has its is_password property set to true.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -302,7 +304,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_array(%args) -> [status, msg, result, meta]
 
-This function has arg with cmdline_src=stdin.
+{en_US This function has arg with cmdline_src=stdin}.
 
 Arguments ('*' denotes required arguments):
 
@@ -326,7 +328,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_line(%args) -> [status, msg, result, meta]
 
-This function has a single stdin_line argument.
+{en_US This function has a single stdin_line argument}.
 
 Arguments ('*' denotes required arguments):
 
@@ -352,7 +354,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_files_array(%args) -> [status, msg, result, meta]
 
-This function has array arg with cmdline_src=stdin_or_files.
+{en_US This function has array arg with cmdline_src=stdin_or_files}.
 
 Arguments ('*' denotes required arguments):
 
@@ -376,7 +378,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_or_files_str(%args) -> [status, msg, result, meta]
 
-This function has str arg with cmdline_src=stdin_or_files.
+{en_US This function has str arg with cmdline_src=stdin_or_files}.
 
 Arguments ('*' denotes required arguments):
 
@@ -400,7 +402,7 @@ Return value:  (any)
 
 =head2 cmdline_src_stdin_str(%args) -> [status, msg, result, meta]
 
-This function has arg with cmdline_src=stdin.
+{en_US This function has arg with cmdline_src=stdin}.
 
 Arguments ('*' denotes required arguments):
 
@@ -424,7 +426,7 @@ Return value:  (any)
 
 =head2 cmdline_src_unknown(%args) -> [status, msg, result, meta]
 
-This function has arg with unknown cmdline_src value.
+{en_US This function has arg with unknown cmdline_src value}.
 
 Arguments ('*' denotes required arguments):
 
@@ -448,10 +450,12 @@ Return value:  (any)
 
 =head2 test_binary(%args) -> [status, msg, result, meta]
 
-Accept binary in stdin/file.
+{en_US Accept binary in stdin/file}.
 
+{en_US 
 This function is like the one in C<Perinci::Examples> but argument is accepted
 via C<stdin_or_files>.
+}
 
 Arguments ('*' denotes required arguments):
 
